@@ -17,22 +17,22 @@ sgbp = function(x, predicate, region.id, ncol) {
 #' @param max_nb integer; maximum number of neighbours to print for each item
 #' @details \code{sgbp} are sparse matrices, stored as a list with integer vectors holding the ordered \code{TRUE} indices of each row. This means that for a dense, \eqn{m \times n}{m x n} matrix \code{Q} and a list \code{L}, if \code{Q[i,j]} is \code{TRUE} then \eqn{j} is an element of \code{L[[i]]}. Reversed: when \eqn{k} is the value of \code{L[[i]][j]}, then \code{Q[i,k]} is \code{TRUE}.
 print.sgbp = function(x, ..., n = 10, max_nb = 10) {
-  n = min(length(x), n)
-  cat("Sparse geometry binary predicate list of length ", length(x), ", ", sep = "")
-  cat("where the predicate was `", attr(x, "predicate"), "'\n", sep = "")
-  if (n < length(x))
-    cat("first ", n, " elements:\n", sep = "")
-  nbh = function(i, m) {
-    X = x[[i]]
-    end = if (length(X) > m) ", ..." else ""
-    cat(" ", i, ": ", sep = "")
-    if (length(X))
-	  cat(paste(head(X, m), collapse = ", "), end, "\n", sep = "")
-	else
-	  cat("(empty)\n")
-  }
-  lapply(1:n, nbh, m = max_nb)
-  invisible(x)
+	n = min(length(x), n)
+	cat("Sparse geometry binary predicate list of length ", length(x), ", ", sep = "")
+	cat("where the predicate was `", attr(x, "predicate"), "'\n", sep = "")
+	if (n < length(x))
+		cat("first ", n, " elements:\n", sep = "")
+	nbh = function(i, m) {
+		X = x[[i]]
+		end = if (length(X) > m) ", ..." else ""
+		cat(" ", i, ": ", sep = "")
+		if (length(X))
+			cat(paste(head(X, m), collapse = ", "), end, "\n", sep = "")
+		else
+			cat("(empty)\n")
+	}
+	lapply(1:n, nbh, m = max_nb)
+	invisible(x)
 }
 
 #' @name sgbp
@@ -70,3 +70,8 @@ Ops.sgbp = function(e1, e2) {
 		region.id = attr(e1, "region.id"),
 		ncol = attr(e1, "ncol"))
 }
+
+#' @export
+as.data.frame.sgbp = function(x, ...) {
+	data.frame(row.id = rep(seq_along(x), lengths(x)), col.id = unlist(x))
+}
