@@ -1,5 +1,4 @@
 library(testthat)
 suppressPackageStartupMessages(library(sf))
 
-#test_check("sf", reporter = RstudioReporter)
-test_check("sf")
+# test_check("sf")
